@@ -11,6 +11,7 @@ from benedict.core import invert as _invert
 from benedict.core import items_sorted_by_keys as _items_sorted_by_keys
 from benedict.core import items_sorted_by_values as _items_sorted_by_values
 from benedict.core import keypaths as _keypaths
+from benedict.core import match as _match
 from benedict.core import merge as _merge
 from benedict.core import move as _move
 from benedict.core import nest as _nest
@@ -36,7 +37,9 @@ class benedict(KeypathDict, IODict, ParseDict):
         Constructs a new instance.
         """
         if len(args) == 1 and isinstance(args[0], benedict):
-            super(benedict, self).__init__(args[0].dict())
+            obj = args[0]
+            kwargs.setdefault('keypath_separator', obj.keypath_separator)
+            super(benedict, self).__init__(obj.dict(), **kwargs)
             return
         super(benedict, self).__init__(*args, **kwargs)
 
@@ -125,7 +128,8 @@ class benedict(KeypathDict, IODict, ParseDict):
 
     def get_list_item(self, key, index=0, default=None, separator=','):
         return self._cast(
-            super(benedict, self).get_list_item(key, index, default, separator))
+            super(benedict, self).get_list_item(
+                key, index, default, separator))
 
     def groupby(self, key, by_key):
         """
@@ -156,12 +160,22 @@ class benedict(KeypathDict, IODict, ParseDict):
         """
         return _items_sorted_by_values(self, reverse=reverse)
 
-    def keypaths(self):
+    def keypaths(self, indexes=False):
         """
         Return a list of all keypaths in the dict.
+        If indexes is True, the output will include list values indexes.
         """
-        sep = self._keypath_separator or '.'
-        return _keypaths(self, separator=sep)
+        return _keypaths(
+            self, separator=self._keypath_separator, indexes=indexes)
+
+    def match(self, pattern, indexes=True):
+        """
+        Return a list of all values whose keypath matches the given pattern (a regex or string).
+        If pattern is string, wildcard can be used (eg. [*] can be used to match all list indexes).
+        If indexes is True, the pattern will be matched also against list values.
+        """
+        return _match(
+            self, pattern, separator=self._keypath_separator, indexes=indexes)
 
     def merge(self, other, *args, **kwargs):
         """
@@ -178,7 +192,8 @@ class benedict(KeypathDict, IODict, ParseDict):
         """
         _move(self, key_src, key_dest)
 
-    def nest(self, key, id_key='id', parent_id_key='parent_id', children_key='children'):
+    def nest(self, key,
+             id_key='id', parent_id_key='parent_id', children_key='children'):
         """
         Nest a list of dicts at the given key and return a new nested list
         using the specified keys to establish the correct items hierarchy.
